@@ -23,8 +23,15 @@
 #include "evolution-webcal-notify.h"
 
 #define WEBCAL_BASE_URI "webcal://"
-#define CALENDAR_SOURCES_KEY "/apps/evolution/calendar/sources"
-#define TASKS_SOURCES_KEY "/apps/evolution/tasks/sources"
+
+#define CALENDAR_CONFIG_PREFIX "/apps/evolution/calendar"
+#define TASKS_CONFIG_PREFIX "/apps/evolution/tasks"
+
+#define SELECTED_CALENDARS_KEY CALENDAR_CONFIG_PREFIX "/display/selected_calendars"
+#define SELECTED_TASKS_KEY CALENDAR_CONFIG_PREFIX "/tasks/selected_tasks"
+
+#define CALENDAR_SOURCES_KEY CALENDAR_CONFIG_PREFIX "/sources"
+#define TASKS_SOURCES_KEY TASKS_CONFIG_PREFIX "/sources"
 
 typedef struct {
   GtkWidget * dialog;
@@ -168,6 +175,31 @@ void e_webcal_display_error (const gchar * title, const gchar * message,
   }
 }
 
+static void select_source (ESource * source, icalcomponent_kind kind) {
+  const char * key = NULL;
+  GConfClient * config = NULL;
+  GSList * list;
+
+  g_return_if_fail (source != NULL);
+
+  if (kind == ICAL_VEVENT_COMPONENT)
+    key = SELECTED_CALENDARS_KEY;
+  else if (kind == ICAL_VTODO_COMPONENT)
+    key = SELECTED_TASKS_KEY;
+  else
+    return;
+
+  config = gconf_client_get_default ();
+
+  list = gconf_client_get_list (config, key, GCONF_VALUE_STRING, NULL);
+  list = g_slist_append (list, (char *) e_source_peek_uid (source));
+  gconf_client_set_list (config, key, GCONF_VALUE_STRING, list, NULL);
+
+  g_slist_free (list);
+
+  g_object_unref (config);
+}
+
 void e_webcal_query_user (const gchar * name, const gchar * desc,
                           const gchar * caluri,
                           gboolean has_events, gboolean has_tasks) {
@@ -198,7 +230,7 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
 
   if (!events_group) {
     /* Create the Webcal source group */
-    events_group = e_source_group_new (_("On The Web"), WEBCAL_BASE_URI);
+    events_group = e_source_group_new ("On The Web", WEBCAL_BASE_URI);
     e_source_list_add_group (events_sources, events_group, -1);
   }
 
@@ -213,7 +245,7 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
 
   if (!tasks_group) {
     /* Create the Webcal source group */
-    tasks_group = e_source_group_new (_("On The Web"), WEBCAL_BASE_URI);
+    tasks_group = e_source_group_new ("On The Web", WEBCAL_BASE_URI);
     e_source_list_add_group (tasks_sources, tasks_group, -1);
   }
 
@@ -426,11 +458,13 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
     if (has_events) {
       e_source_group_add_source (events_group, source, -1);
       e_source_list_sync (events_sources, NULL);
+      select_source (source, ICAL_VEVENT_COMPONENT);
     }
 
     if (has_tasks) {
       e_source_group_add_source (tasks_group, source, -1);
       e_source_list_sync (tasks_sources, NULL);
+      select_source (source, ICAL_VTODO_COMPONENT);
     }
 
     /* We fall through to the CANCEL/default cases to handle all the unreffing
